@@ -45,7 +45,7 @@ class Testdrive:
 		self.r = None #Release (maverick, lucid, etc)
 		self.m = None #Arch (amd64, i386)
 		self.f = None #Flavor (ubuntu, kubuntu, etc)
-		self.p = None # Ubuntu ISO Repository (cdimage, releases)
+		self.p = None # Ubuntu ISO Repository (cdimage, releases, uec-daily, uec-releases)
 
 	def set_values(self, var, value):
 		if var == 'kvm_args':
@@ -60,6 +60,8 @@ class Testdrive:
 			self.CACHE = value
 		if var == 'cache_img':
 			self.CACHE_IMG = value
+		if var == 'cache_iso':
+			self.CACHE_ISO = value
 		if var == 'clean_img':
 			self.CLEAN_IMG = value
 		if var == 'iso_url':
@@ -100,28 +102,44 @@ class Testdrive:
 			if iso.split()[1] == self.r:
 				# TODO: Add support for UEC
 				category = iso.split()[0]
-				if category == 'ubuntu-netbook':
+				if category == 'ubuntu-server':
 					category = 'ubuntu'
-				elif category == 'ubuntu-server':
+				elif category == 'ubuntu-netbook':
+					category = 'ubuntu'
+				elif category == 'ubuntu-mobile':
 					category = 'ubuntu'
 				elif category == 'kubuntu-netbook':
 					category = 'kubuntu'
+				elif category == 'kubuntu-mobile':
+					category = 'kubuntu'
 				flavor = iso.split()[0].capitalize()
 				if flavor == 'Ubuntu-netbook':
 					flavor = 'Ubuntu'
+				elif flavor == 'Ubuntu-mobile':
+					flavor == 'Ubuntu'
 				elif flavor == 'Kubuntu-netbook':
 					flavor = 'Kubuntu'
+				elif flavor == 'Kubuntu-mobile':
+					flavor = 'Kubuntu'
 				elif flavor == 'Ubuntustudio':
 					flavor = 'Ubuntu Studio'
 				elif flavor == 'Ubuntu-server':
 					flavor = 'Ubuntu'
+				elif flavor == 'Uec-server':
+					flavor = 'UEC Server'
+				elif flavor == 'Uec-desktop':
+					flavor = 'UEC Desktop'
 				release = iso.split()[1]
 				url = iso.split()[2]
-				arch = url.split(".iso")[0].split("-")[-1]
-				image = url.split("-%s.iso" % arch)[0].split("-")[-1].capitalize()
-				if image == 'Dvd':
-					image = url.split("-%s.iso" % arch)[0].split("-")[-1].swapcase()
-				name = "%s %s" % (flavor, image)
+				if self.p == 'uec-daily' or self.p == 'uec-releases':
+					arch = url.split(".tar.gz")[0].split("-")[-1]
+					name = "%s" % flavor 
+				else:
+					arch = url.split(".iso")[0].split("-")[-1]
+					image = url.split("-%s.iso" % arch)[0].split("-")[-1].capitalize()
+					if image == 'Dvd':
+						image = url.split("-%s.iso" % arch)[0].split("-")[-1].swapcase()
+					name = "%s %s" % (flavor, image)
 				# Name: Shows a description
 				# URL: Shows the URL from where it downloads the ISO
 				# Arch: Shows the architecture (amd64|i386)
@@ -214,6 +232,9 @@ class Testdrive:
 		if self.p == 'releases':
 			self.u = 'rsync://us.rsync.releases.ubuntu.com/releases'
 
+		if self.p == 'uec-daily' or self.p == 'uec-releases':
+			self.u = 'rsync://uec-images.ubuntu.com/uec-images'
+
 	def run(self, cmd):
 		return(os.system(cmd))
 
@@ -270,6 +291,8 @@ class Testdrive:
 			elif os.path.getsize(self.DISK_FILE) == 0:
 				# Clean up empty file
 				rm_disk = True
+			elif self.p == 'uec-daily' or self.p == 'uec-releases':
+				rm_disk = True
 			if rm_disk:
 				#info("Cleaning up disk image [%s]..." % DISK_FILE)
 				os.unlink(self.DISK_FILE)
@@ -316,6 +339,10 @@ class Testdrive:
 			(status, output) = commands.getstatusoutput("wget -q -O- http://cdimage.ubuntu.com/.manifest-daily | egrep '(amd64|i386)'")
 		elif self.p == 'releases':
 			(status, output) = commands.getstatusoutput("wget -q -O- http://releases.ubuntu.com/.manifest | egrep '(amd64|i386)'")
+		elif self.p == 'uec-daily':
+			(status, output) = commands.getstatusoutput("wget -q -O- http://uec-images.ubuntu.com/.manifest-daily | egrep '(amd64|i386)'")
+		elif self.p == 'uec-releases':
+			(status, output) = commands.getstatusoutput("wget -q -O- http://uec-images.ubuntu.com/.manifest | egrep '(amd64|i386)'")
 		return output
 
 	def update_ubuntu_iso_list_cache(self, str):
@@ -344,3 +371,15 @@ class Testdrive:
 
 	def create_disk_file(self):
 		return tempfile.mkstemp(".img", "testdrive-disk-", "%s" % self.CACHE_IMG)[1]
+
+	def prepare_image_tarball(self):
+		untar = False
+		TAR_BASENAME = os.path.basename(self.PATH_TO_ISO).split(".tar.gz")[0].split("_")[-1]
+		ORIG_DISK_NAME = "%s.img" % TAR_BASENAME
+		FLOPPY_NAME = "%s-floppy" % TAR_BASENAME
+
+		image_path = "%s/%s" % (self.CACHE_ISO, ORIG_DISK_NAME)
+		floppy_path = "%s/%s" % (self.CACHE_ISO, FLOPPY_NAME)
+
+		cmd = 'cd %s && tar Szxvf %s %s %s' % (self.CACHE_ISO, self.PATH_TO_ISO, ORIG_DISK_NAME, FLOPPY_NAME)
+		os.system(cmd)
