@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 ### BEGIN LICENSE
 # Copyright (C) 2010 Canonical Ltd.
 # 
@@ -96,6 +96,8 @@ class PreferencesTestdrivegtkDialog(gtk.Dialog):
 		self.initialize_widgets()
 		self.initialize_widgets_values()
 		self.logger.debug(_('finish_initialization()'))
+		
+		self.builder.get_object("txt_gral_cache")
 
 	def initialize_variables(self):
 		self.virt_method = None
@@ -130,7 +132,7 @@ class PreferencesTestdrivegtkDialog(gtk.Dialog):
 		self.chk_arch_amd64.connect("clicked", self.on_select_arch, "amd64")
 
 		# Ubuntu Repositories Combo Box
-		self.tb_ubuntu_release_prefs = self.builder.get_object("tb_ubuntu_release_prefs")
+		self.tb_general_prefs = self.builder.get_object("tb_general_prefs")
 		self.cb_ubuntu_repo = gtk.combo_box_new_text()
 		self.cb_ubuntu_repo.set_size_request(260, -1)
 		self.cb_ubuntu_repo.append_text(_('Select Repository:'))
@@ -139,7 +141,7 @@ class PreferencesTestdrivegtkDialog(gtk.Dialog):
 		self.cb_ubuntu_repo.connect('changed', self.on_select_iso_image_repo)
 		self.cb_ubuntu_repo.set_active(0)
 		self.cb_ubuntu_repo.show()
-		self.tb_ubuntu_release_prefs.attach(self.cb_ubuntu_repo, 1,2,0,1, gtk.FILL)
+		self.tb_general_prefs.attach(self.cb_ubuntu_repo, 1,2,7,8)
 		# Ubuntu Releases Combo Box
 		self.cb_ubuntu_release = gtk.combo_box_new_text()
 		self.cb_ubuntu_release.set_size_request(260, -1)
@@ -147,7 +149,7 @@ class PreferencesTestdrivegtkDialog(gtk.Dialog):
 		self.cb_ubuntu_release.append_text(_('Select Release:'))
 		self.cb_ubuntu_release.set_active(0)
 		self.cb_ubuntu_release.show()
-		self.tb_ubuntu_release_prefs.attach(self.cb_ubuntu_release, 1,2,1,2, gtk.FILL)
+		self.tb_general_prefs.attach(self.cb_ubuntu_release, 1,2,8,9)
 		
 		# Initialize Virtualization Method Options
 		self.opt_virt_kvm = self.builder.get_object("opt_virt_kvm")
@@ -256,7 +258,7 @@ class PreferencesTestdrivegtkDialog(gtk.Dialog):
 		elif self.td.DISK_SIZE == '8G':
 			self.cbe_disk_size.set_active(2)
 		else:
-			self.cbe_disk_size.append_text(self.td.DISK_SIZE.replace('G', ''))
+			self.cbe_disk_size.append_text(self.td.DISK_SIZE.replace("G", ""))
 			self.cbe_disk_size.set_active(4)
 
 		# KVM Args
@@ -514,13 +516,13 @@ class PreferencesTestdrivegtkDialog(gtk.Dialog):
 		##################################################################
 		self.preferences = []
 		# CACHE Variables
-		if self.td.CACHE != self.txt_gral_cache.get_text():
+		if self.txt_gral_cache.get_text() != None:
 			self.td.CACHE = self.txt_gral_cache.get_text()
 			self.preferences.append(['cache', self.td.CACHE])
-		if self.td.CACHE_IMG != self.txt_img_cache.get_text():
+		if self.txt_img_cache.get_text() != None:
 			self.td.CACHE_IMG = self.txt_img_cache.get_text()
 			self.preferences.append(['cache_img', self.td.CACHE_IMG])
-		if self.td.CACHE_ISO != self.txt_iso_cache.get_text():
+		if self.txt_iso_cache.get_text() != None:
 			self.td.CACHE_ISO = self.txt_iso_cache.get_text()
 			self.preferences.append(['cache_iso', self.td.CACHE_ISO])
 
@@ -528,49 +530,46 @@ class PreferencesTestdrivegtkDialog(gtk.Dialog):
 		if self.repo != None:
 			self.preferences.append(['p', self.td.p])
 
-		if self.td.r != self.r:
+		if self.r != None:
 			self.td.r = self.r
-			if self.r !=None:
-				self.preferences.append(['r', self.td.r])
+			self.preferences.append(['r', self.td.r])
 
 		# KVM Args
-		if self.td.KVM_ARGS != self.txt_kvm_args.get_text():
+		if self.txt_kvm_args.get_text() != None:
 			self.td.KVM_ARGS = self.txt_kvm_args.get_text()
 			self.preferences.append(['kvm_args', self.td.KVM_ARGS])
 
-		if self.td.SMP != self.txt_smp_nbr.get_text():
+		if self.txt_smp_nbr.get_text() != None:
 			self.td.SMP = self.txt_smp_nbr.get_text()
 			self.preferences.append(['smp', self.td.SMP])
 
 		#ARCHs
 		if 'amd64' in self.arch and 'i386' in self.arch:
 			self.td.m = self.arch
-			pass
 		elif 'amd64' in self.arch or 'i386' in self.arch:
 			self.td.m = self.arch
 			self.preferences.append(['m', self.td.m[0]])
 
 		# VIRT Methods
-		if self.td.VIRT != self.virt_method and self.virt_method != None:
+		if self.virt_method != None:
 			self.td.VIRT = self.virt_method
 			self.preferences.append(['virt', self.td.VIRT])
 
 		# Memory - TODO: Add validation of text
 		if self.mem == 'other':
 			self.mem = self.cbe_mem_size.child.get_text()
-		if self.td.MEM != self.mem or self.mem not in MEM_SIZE_TAB:
+		if self.mem != None or self.mem not in MEM_SIZE_TAB:
 			self.td.MEM = self.mem
 			self.preferences.append(['mem', self.td.MEM])
 
 		# Disk Size - TODO: Add validation of text
 		if self.disk_size == 'other':
 			self.disk_size = self.cbe_disk_size.child.get_text()
-		if self.td.DISK_SIZE.replace('G','') != self.disk_size or self.disk_size not in DISK_SIZE_TAB:
+		if self.disk_size != None or self.disk_size not in DISK_SIZE_TAB:
 			self.td.DISK_SIZE = "%sG" % self.disk_size
 			self.preferences.append(['disk_size', self.td.DISK_SIZE])
 
 		# Flavors
-		#if self.td.f != self.flavors[:-2]:
 		self.td.f = self.flavors[:-2]
 		self.preferences.append(['f', self.td.f])
 
